@@ -1,5 +1,12 @@
 # -*- coding: utf-8 -*-
 import datetime
+from django.core.files.base import ContentFile
+from django.core.files.storage import default_storage
+try:
+    from django.utils import lorem_ipsum
+except ImportError:
+    # Support Django < 1.8
+    from django.contrib.webdesign import lorem_ipsum
 import os
 import random
 import re
@@ -139,29 +146,32 @@ class LoremGenerator(Generator):
         super(LoremGenerator, self).__init__(*args, **kwargs)
 
     def generate(self):
-        from django.contrib.webdesign.lorem_ipsum import paragraphs, sentence, \
-            words
         if self.method == 'w':
-            lorem = words(self.count, common=self.common)
+            lorem = lorem_ipsum.words(self.count, common=self.common)
         elif self.method == 's':
-            lorem = u' '.join([sentence()
+            lorem = u' '.join([
+                lorem_ipsum.sentence()
                 for i in range(self.count)])
         else:
-            paras = paragraphs(self.count, common=self.common)
+            paras = lorem_ipsum.paragraphs(self.count, common=self.common)
             if self.method == 'p':
                 paras = ['<p>%s</p>' % p for p in paras]
             lorem = u'\n\n'.join(paras)
         if self.max_length:
-            length = random.randint(round(self.max_length / 10), self.max_length)
+            length = random.randint(round(self.max_length / 10),
+                                    self.max_length)
             lorem = lorem[:max(1, length)]
         return lorem.strip()
 
+
 class LoremSentenceGenerator(LoremGenerator):
     method = 's'
 
+
 class LoremHTMLGenerator(LoremGenerator):
     method = 'p'
 
+
 class LoremWordGenerator(LoremGenerator):
     count = 7
     method = 'w'
@@ -594,38 +604,37 @@ class ImageGenerator(Generator):
         (400,600),
     )
 
-    filename = '{width}x{height}-{suffix}.png'
-
-    def __init__(self, width=None, height=None, sizes=None, path='_autofixture', *args, **kwargs):
+    def __init__(self, width=None, height=None, sizes=None,
+                 path='_autofixture', storage=None, *args, **kwargs):
         self.width = width
         self.height = height
         self.sizes = list(sizes or self.default_sizes)
         if self.width and self.height:
             self.sizes.append((width, height))
         self.path = path
+        self.storage = storage or default_storage
         super(ImageGenerator, self).__init__(*args, **kwargs)
 
+    def generate_file_path(self, width, height, suffix=None):
+        suffix = suffix if suffix is not None else ''
+        filename ='{width}x{height}{suffix}.png'.format(
+            width=width, height=height, suffix=suffix)
+        return os.path.join(self.path, filename)
+
     def generate(self):
-        import uuid
-        from django.conf import settings
-        from placeholder import PlaceHolderImage
+        from .placeholder import get_placeholder_image
 
         width, height = random.choice(self.sizes)
 
         # Ensure that _autofixture folder exists.
-        if not os.path.isdir(os.path.join(settings.MEDIA_ROOT, self.path)):
-            os.makedirs(os.path.join(settings.MEDIA_ROOT, self.path))
-
         i = 0
-        filename = self.filename.format(width=width, height=height, suffix=i)
-        filepath = os.path.join(settings.MEDIA_ROOT, self.path, filename)
+        path = self.generate_file_path(width, height)
 
-        while os.path.exists(filepath):
+        while self.storage.exists(path):
             i += 1
-            filename = self.filename.format(width=width, height=height, suffix=i)
-            filepath = os.path.join(settings.MEDIA_ROOT, self.path, filename)
+            path = self.generate_file_path(width, height, '_{0}'.format(i))
 
-        img = PlaceHolderImage(width=width, height=height, path=filepath)
-        img.save_image()
-
-        return relpath(filepath, settings.MEDIA_ROOT)
+        return self.storage.save(
+            path,
+            ContentFile(get_placeholder_image(width, height))
+        )
